fars_read: Load farse data from csv file

View source: R/fars_functions.R

fars_readR Documentation

Load farse data from csv file

Description

This function will used to import csv file to tydeverse tibble format. Import will check if file exists. In case that file does not exist, function will stop.

Usage

fars_read(filename)

Arguments

filename

A csv file name that will be imported into tibble

Value

This function will return tibble from imported csv


BendaVladimir/RPackagesWeek4 documentation built on May 9, 2022, 8:31 p.m.