fars_read_years: Function fars_read_years reads in multiple files and creates...

View source: R/fars_functions.R

fars_read_yearsR Documentation

Function fars_read_years reads in multiple files and creates list of tibbls

Description

Function will take in vector of years, either in string or numbers. fars_read_years will use functions make_filename, to create file name to by loaded into list. Function fars_read will be also used in order to read in cvs files. Final step of the function will be adding new column year from variable year.

Usage

fars_read_years(years)

Arguments

years

Requires vector of years, that will be imported into list of tibbles

Details

fars_read_years will have check on existance of csv file with year, that was entered in vector of years.

Value

Function will return list of tibbles

Examples


fars_read_years(c(2013, 2014))
fars_read_years(c('2013', '2014'))


BendaVladimir/RPackagesWeek4 documentation built on May 9, 2022, 8:31 p.m.