fars_summarize_years: Function fars_summarize_years creates summarized version of...

View source: R/fars_functions.R

fars_summarize_yearsR Documentation

Function fars_summarize_years creates summarized version of years and months

Description

This function uses output from fars_read_years which has output of list of tibbles. Secund step is creating union of all tibbles into one table. Third step is creating summaries of number combinations by year and month. final step is to create new table with values of month in columns and number of existing combinations as values in columns.

Usage

fars_summarize_years(years)

Arguments

years

A character string giving the text the function will print

Value

This function will return tibble of values that have number of combinations of months and years.


BendaVladimir/RPackagesWeek4 documentation built on May 9, 2022, 8:31 p.m.