make_filename: Create name of file from year

View source: R/fars_functions.R

make_filenameR Documentation

Create name of file from year

Description

Simple function, that will create file name from imput string or number. In case that input is not numeric, than function changes type to numeric.

Usage

make_filename(year)

Arguments

year

This parameter defines a year for which file will be imported

Value

Returns string that contains file name

Examples


make_filename('2015')
make_filename(2015)


BendaVladimir/RPackagesWeek4 documentation built on May 9, 2022, 8:31 p.m.