View source: R/fars_functions.R
| fars_read | R Documentation |
This function will used to import csv file to tydeverse tibble format. Import will check if file exists. In case that file does not exist, function will stop.
fars_read(filename)
filename |
A csv file name that will be imported into tibble |
This function will return tibble from imported csv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.