View source: R/fars_functions.R
| fars_read_years | R Documentation |
Function will take in vector of years, either in string or numbers. fars_read_years will use functions make_filename, to create file name to by loaded into list. Function fars_read will be also used in order to read in cvs files. Final step of the function will be adding new column year from variable year.
fars_read_years(years)
years |
Requires vector of years, that will be imported into list of tibbles |
fars_read_years will have check on existance of csv file with year, that was entered in vector of years.
Function will return list of tibbles
fars_read_years(c(2013, 2014))
fars_read_years(c('2013', '2014'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.