View source: R/fars_functions.R
| fars_summarize_years | R Documentation |
This function uses output from fars_read_years which has output of list of tibbles. Secund step is creating union of all tibbles into one table. Third step is creating summaries of number combinations by year and month. final step is to create new table with values of month in columns and number of existing combinations as values in columns.
fars_summarize_years(years)
years |
A character string giving the text the function will print |
This function will return tibble of values that have number of combinations of months and years.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.