View source: R/fars_functions.R
| make_filename | R Documentation |
Simple function, that will create file name from imput string or number. In case that input is not numeric, than function changes type to numeric.
make_filename(year)
year |
This parameter defines a year for which file will be imported |
Returns string that contains file name
make_filename('2015')
make_filename(2015)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.